--[[
****************************************************************************************

ARLFrame.lua

Frame functions for all of AckisRecipeList

$Date: 2008-05-10 18:28:18 -0400 (Sat, 10 May 2008) $
$Rev: 73394 $

****************************************************************************************
]]--

local L			= LibStub("AceLocale-3.0"):GetLocale("AckisRecipeList")
local Crayon	= LibStub("LibCrayon-3.0")

-- Prototype: http://i30.tinypic.com/2hoxncl.jpg
-- I want to turn the GUI into that, but prettier... most functionality is in already, all the tables etc are created, just need to actually use the information now.

-- Calculates the total height of all the recipes in the child frame

local function CalculateChildHeight()

	local tempheight = 0
	local RecipeFrame = AckisRecipeListRecipe1

	while (RecipeFrame ~= nil) do
		tempheight = RecipeFrame:GetHeight() + RecipeFrame.RecipeAquireText:GetHeight() + tempheight
		RecipeFrame = RecipeFrame.NextRecipe
	end

	return tempheight

end

-- Adds recipe text info to the frames
-- Function to run when the + is clicked in the frame.  Will expand the recipe name and print out how to obtain it.

local function ARL_OnClickExpandRecipe()

	if (this.IsPushed == false) then
		local RecipeText = nil

		local sorttype = ARL.db.profile.sorting

		if (sorttype == "Skill") or (sorttype == "Aquisition") then
			RecipeText = string.match(this:GetText(), "|c.*%[.*%]|r %- (.*)")
		elseif (sorttype == "Name") then
			RecipeText = string.match(this:GetText(), "(.*) %- |c.*%[.*%]|r")
		end

		-- Changed the graphic of the + to a -
		this:SetNormalTexture("Interface\\Buttons\\UI-MinusButton-Up")
		this:SetPushedTexture("Interface\\Buttons\\UI-MinusButton-Down")
		this:SetHighlightTexture("Interface\\Buttons\\UI-MinusButton-Hilight")

		-- Keep track of button state
		this.IsPushed = true

		-- Show expanded text
		if (ARL.MissingRecipeListing[RecipeText] == nil) then
			this.RecipeAquireText:SetText(L["Unknown"])
		else
			this.RecipeAquireText:SetText("    - " .. ARL.MissingRecipeListing[RecipeText]["Acquire"])
		end

		this.RecipeAquireText:SetWidth(300)

		this.RecipeAquireText:Show()

		-- Reposition the next recipe entry
		if (this.NextRecipe ~= nil) then
			this.NextRecipe:ClearAllPoints()
			this.NextRecipe:SetPoint("TOPLEFT", this.RecipeAquireText, "BOTTOMLEFT", -20, -5)
		end

	else

		-- Changed the graphic of the - to a +
		this:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
		this:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
		this:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")

		-- Keep track of button state
		this.IsPushed = false

		-- Hide expanded text
		this.RecipeAquireText:SetText("")
		this.RecipeAquireText:Hide()

		-- Reposition the next recipe entry
		if (this.NextRecipe ~= nil) then
			this.NextRecipe:ClearAllPoints()
			this.NextRecipe:SetPoint("TOPLEFT", this, "BOTTOMLEFT", 0, 0)
		end
	end

	ARL.Frame.ScrollFrame:UpdateScrollChildRect()

end

-- Adds recipe text info to the frames

local function ARL_AddRecipeInfo(CurrentProfession, CurrentProfessionLevel, SortedList, CurrentSpeciality)

	local OldFrame = nil
	local RecipeFrame = nil
	local RecipeCount = 1
	
	for i, RecipeName in ipairs(SortedList) do

		if (ARL:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality)) then

			-- If the frame isn't created, then create it and set the parameters for it, otherwise use the current frame (recycle it)
			if (not _G["AckisRecipeListRecipe" .. RecipeCount]) then
				RecipeFrame = CreateFrame("Button", "AckisRecipeListRecipe" .. RecipeCount, ARL.Frame.ScrollChild, "ClassTrainerSkillButtonTemplate")
				RecipeFrame:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
				RecipeFrame:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
				RecipeFrame:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")
				RecipeFrame:SetTextColor(1, 1, 1)
				RecipeFrame:SetWidth(18)
				RecipeFrame:SetScript("OnClick",
											ARL_OnClickExpandRecipe
									)
				RecipeFrame:SetScript("OnLeave", function()
											GameTooltip:Hide()
										end
							)
				RecipeFrame.IsPushed = false

				-- Create aquire text for the recipe
				RecipeFrame.RecipeAquireText = RecipeFrame:CreateFontString("AckisRecipeListRecipe" .. RecipeCount .. "Text", "DIALOG")

				RecipeFrame.RecipeAquireText:ClearAllPoints()
				RecipeFrame.RecipeAquireText:SetPoint("TOPLEFT", RecipeFrame, "BOTTOMLEFT", 20, 0)
				RecipeFrame.RecipeAquireText:SetFontObject("GameFontNormalSmall")
				RecipeFrame.RecipeAquireText:SetTextColor(1, 1, 1)
				RecipeFrame.RecipeAquireText:SetJustifyH("LEFT")

			else

				-- Grab the frame from the global stack
				RecipeFrame = _G["AckisRecipeListRecipe" .. RecipeCount]

			end

			-- If we have a previous recipe, set the previous recipe next recipe to this current recipe
			if (OldFrame ~= nil) then
				OldFrame.NextRecipe = RecipeFrame
			end

			-- If we're at the last recipe, set the next reicpe to nil, otherwise set the previous entries nextrecipe to a temp variable.
			local NumMissingRecipes = ARL.NumberOfRecipes - ARL.FoundRecipes
			if (i == NumMissingRecipes) then
				RecipeFrame.NextRecipe = nil
			else
				OldFrame = RecipeFrame
			end

			RecipeFrame:ClearAllPoints()

			-- If we're on the first recipe, set the points in relation to the main frame, otherwise set them in relation to the previous recipe
			if (RecipeCount == 1) then
				RecipeFrame:SetPoint("TOPLEFT", ARL.Frame.ScrollChild, "TOPLEFT", 5, -30)
			else
				RecipeFrame:SetPoint("TOPLEFT", "AckisRecipeListRecipe" .. (RecipeCount - 1), "BOTTOMLEFT", 0, -1)
			end

			local temprecipetext

			local sorttype = ARL.db.profile.sorting

			if (sorttype == "Skill") or (sorttype == "Aquisition") then
				if (ARL.MissingRecipeListing[RecipeName]["Level"] > CurrentProfessionLevel) then
					temprecipetext = Crayon:Red("[" .. ARL.MissingRecipeListing[RecipeName]["Level"] .. "]") .. " - " .. RecipeName
				else
					temprecipetext = Crayon:White("[" .. ARL.MissingRecipeListing[RecipeName]["Level"] .. "]") .. " - " .. RecipeName
				end
			elseif (sorttype == "Name") then
				if (ARL.MissingRecipeListing[RecipeName]["Level"] > CurrentProfessionLevel) then
					temprecipetext = RecipeName .. " - " .. Crayon:Red("[" .. ARL.MissingRecipeListing[RecipeName]["Level"] .. "]")
				else
					temprecipetext = RecipeName .. " - " .. Crayon:White("[" .. ARL.MissingRecipeListing[RecipeName]["Level"] .. "]")
				end
			end

			RecipeFrame:SetText(temprecipetext)
			RecipeFrame:SetScript("OnEnter", function(this)
					GameTooltip_SetDefaultAnchor(GameTooltip, this)
					GameTooltip:SetText(temprecipetext .. ARL.br .. ARL.MissingRecipeListing[RecipeName]["Acquire"])
					GameTooltip:Show()
				end
			)

			RecipeFrame:Show()
			RecipeCount = RecipeCount + 1
		end

	end

end

-- Closes the frame and cleans sets everything that was displayed to nil

function ARL:CloseWindow()

	-- Clean up recipe entries
	local RecipeFrame = AckisRecipeListRecipe1

	-- Clear x number of entries for all missing recipes
	while (RecipeFrame ~= nil) do
		RecipeFrame.RecipeAquireText:SetText("")
		RecipeFrame.RecipeAquireText:Hide()

		RecipeFrame:SetText("")
		RecipeFrame:Hide()

		if (RecipeFrame.IsPushed == true) then
			RecipeFrame:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
			RecipeFrame:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
			RecipeFrame:SetDisabledTexture("Interface\\Buttons\\UI-PlusButton-Disabled")
			RecipeFrame:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")
			RecipeFrame.IsPushed = false
		end

		RecipeFrame.RecipeAquireText:SetText("")
		RecipeFrame.RecipeAquireText:Hide()
		RecipeFrame = RecipeFrame.NextRecipe
	end

	ARL.Frame:Hide()

	ARL.ResetOkayARL = true

	if (ARL_ResetOkayBlizz and ARL.ResetOkayARL) then
		ARL:ARL_ResetVariables()
	end

end

-- Expands all the headers

function ARL:ExpandAll()

	local frame = _G["AckisRecipeListRecipe1"]

	if (frame) then
		if (frame.IsPushed == false) then
			frame:ARL_OnClickExpandRecipe()
		end
	end

end

-- Closes all the headers

function ARL:CloseAll()

	local frame = _G["AckisRecipeListRecipe1"]

	if (frame) then
		if (frame.IsPushed == true) then
			frame:ARL_OnClickExpandRecipe()
		end
	end

end

-- Create the scan button and add it to Skillet if applicable

function ARL:CreateScanButton()
	-- Create the scan button
	if (not ARL.ScanButton) then
		ARL.ScanButton = CreateFrame("Button","ARL.ScanButton",UIParent,"UIPanelButtonTemplate")
	end

	-- Add to Skillet interface
	if (Skillet and Skillet:IsActive()) then
		ARL.ScanButton:SetParent(SkilletFrame)
		ARL.ScanButton:Show()
		ARL.ScanButton:SetTextColor(1, 0.8, 0)
		Skillet:AddButtonToTradeskillWindow(ARL.ScanButton)
		ARL.ScanButton:SetWidth(80)
	end

	-- Set some of the common button properties
	ARL.ScanButton:SetHeight(20)
	ARL.ScanButton:RegisterForClicks("LeftButtonUp")
	ARL.ScanButton:SetScript("OnClick", function()
											ARL:ToggleFrame()
										end
							)
	ARL.ScanButton:SetScript("OnEnter", function(this)
											GameTooltip_SetDefaultAnchor(GameTooltip, this)
											GameTooltip:SetText(L["Scan Skills Long"])
											GameTooltip:Show()
										end
							)
	ARL.ScanButton:SetScript("OnLeave", function()
											GameTooltip:Hide()
										end
							)
	ARL.ScanButton:SetText(L["ScanButton"])
	ARL.ScanButton:SetFrameStrata("DIALOG")
	ARL.ScanButton:Enable()
end

-- Adds a button to the trade skill/skillet/crafting skill window allowing you to scan

function ARL:ShowScanButton()
	-- Add to ATSW
	if (ATSWFrame and not CraftIsPetTraining()) then
		ARL.ScanButton:SetParent(ATSWFrame)
		ARL.ScanButton:ClearAllPoints()
		ARL.ScanButton:SetPoint("RIGHT", ATSWOptionsButton, "LEFT", 0, 0)
		ARL.ScanButton:SetTextColor(ATSWOptionsButton:GetTextColor())
		ARL.ScanButton:SetHeight(ATSWOptionsButton:GetHeight())
		ARL.ScanButton:SetWidth(80)
	elseif (ARL.SkillType == "Trade") then
	-- Anchor to trade window
		ARL.ScanButton:SetParent(TradeSkillFrame)
		ARL.ScanButton:ClearAllPoints()
		ARL.ScanButton:SetPoint("RIGHT",TradeSkillFrameCloseButton,"LEFT",10,0)
		ARL.ScanButton:SetTextColor(1, 1, 0)
		ARL.ScanButton:SetWidth(ARL.ScanButton:GetTextWidth() + 10)
	-- Anchor to crafting window
	elseif (ARL.SkillType == "Craft") then
		ARL.ScanButton:SetParent(CraftFrame)
		ARL.ScanButton:ClearAllPoints()
		ARL.ScanButton:SetPoint("RIGHT",CraftFrameCloseButton,"LEFT",10,0)
		ARL.ScanButton:SetTextColor(1, 1, 0)
		ARL.ScanButton:SetWidth(ARL.ScanButton:GetTextWidth() + 10)
	end

	ARL.ScanButton:Show()
end

-- Allows the scan button to close the scan window

function ARL:ToggleFrame()
	if (ARL.Frame and ARL.Frame:IsVisible()) then
		ARL.Frame:Hide()
	else
		ARL:AckisRecipeList_Command()
	end
end

-- Creates the initial frame to display recipes into

function ARL:CreateFrame(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

	ARL.ResetOkayARL = false

	if (not ARL.Frame) then

		-- Create the main frame
		ARL.Frame = CreateFrame("Frame", "ARL.Frame", UIParent)
		--Allows ARL to be closed with the Escape key
		tinsert(UISpecialFrames, "ARL.Frame")

		ARL.Frame:SetWidth(384)
		ARL.Frame:SetHeight(430)
		ARL.Frame:SetBackdrop(
		{
			bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",
			edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
			tile="false",
			edgeSize = 16,
			insets = {
						left = 5,
						right = 5,
						top = 5,
						bottom = 5
					}
		})
		ARL.Frame:SetBackdropColor(0, 0, 0)
		ARL.Frame:EnableMouse(true)
		ARL.Frame:EnableKeyboard(true)
		ARL.Frame:SetMovable(true)
		ARL.Frame:SetScript("OnMouseDown", function() 
												ARL.Frame:StartMoving()
											end
							)
		ARL.Frame:SetScript("OnHide", function()
												ARL:CloseWindow()
											end
							)
		ARL.Frame:SetScript("OnMouseUp", function()
												ARL.Frame:StopMovingOrSizing()
											end
							)

		-- ATSW for some reason has a window "bigger" than what you can see
		if (ATSWFrame and not CraftIsPetTraining()) then
			ARL.Frame:SetFrameStrata("DIALOG")
		end

		-- Add header frame
		ARL.Frame.Header = CreateFrame("Frame", "ARL.Frame.Header", ARL.Frame)

		ARL.Frame.Header:SetWidth(192)
		ARL.Frame.Header:SetHeight(32)
		ARL.Frame.Header:ClearAllPoints()
		ARL.Frame.Header:SetPoint("TOP", ARL.Frame, "TOP", 0, 6)
		ARL.Frame.Header:EnableMouse(true)
		ARL.Frame.Header:SetMovable(true)
		ARL.Frame.Header:SetScript("OnMouseDown", function()
														ARL.Frame:StartMoving()
													end
									)
		ARL.Frame.Header:SetScript("OnMouseUp", function()
													ARL.Frame:StopMovingOrSizing()
												end
									)

		-- Add texture to the header frame
		ARL.Frame.Header.Texture = ARL.Frame.Header:CreateTexture("ARL.Frame.Header.Texture", "ARTWORK")

		ARL.Frame.Header.Texture:SetTexture("Interface\\DialogFrame\\UI-DialogBox-Header")
		ARL.Frame.Header.Texture:SetWidth(384)
		ARL.Frame.Header.Texture:SetHeight(64)
		ARL.Frame.Header.Texture:ClearAllPoints()
		ARL.Frame.Header.Texture:SetPoint("TOP", ARL.Frame.Header, "TOP", 0, 5)
		--ARL.Frame.Header.Texture:SetPoint("TOP", ARL.Frame.Header, "TOP", 0, 0)

		-- Add text to header frame
		ARL.Frame.Header.Text = ARL.Frame.Header:CreateFontString("ARL.Frame.Header.Text", "ARTWORK")

		ARL.Frame.Header.Text:SetFontObject(GameFontNormal)
		ARL.Frame.Header.Text:ClearAllPoints()
		ARL.Frame.Header.Text:SetPoint("CENTER", ARL.Frame.Header, "CENTER", 0, 0)
		ARL.Frame.Header.Text:SetText(ARL.ARLTitle)

		-- Add close button
		ARL.Frame.CloseButton = CreateFrame("Button", "ARL.Frame.CloseButton", ARL.Frame, "UIPanelButtonTemplate")

		ARL.Frame.CloseButton:SetWidth(100)
		ARL.Frame.CloseButton:SetHeight(24)
		ARL.Frame.CloseButton:ClearAllPoints()
		ARL.Frame.CloseButton:SetPoint("BOTTOMRIGHT", ARL.Frame, -10, 10)
		ARL.Frame.CloseButton:RegisterForClicks("LeftButtonUp")
		ARL.Frame.CloseButton:SetScript("OnClick", function()
														ARL:CloseWindow()
													end
										)
		ARL.Frame.CloseButton:SetFont("GameFontHighlightSmall",12)
		ARL.Frame.CloseButton:Enable()
		ARL.Frame.CloseButton:SetTextColor(1, 1, 1)
		ARL.Frame.CloseButton:SetText(L["Close"])

		-- Add a "close with x" button
		ARL.Frame.XButton = CreateFrame("Button", "ARL.Frame.XButton", ARL.Frame, "UIPanelCloseButton")

		ARL.Frame.XButton:ClearAllPoints()
		ARL.Frame.XButton:SetPoint("TOPRIGHT", ARL.Frame, "TOPRIGHT", 0, 0)
		ARL.Frame.XButton:RegisterForClicks("LeftButtonUp")
		ARL.Frame.XButton:SetScript("OnClick", function()
																ARL:CloseWindow()
															end
											)
		ARL.Frame.XButton:Enable()

		-- Adds scroll frame to mainframe
		ARL.Frame.ScrollFrame = CreateFrame("ScrollFrame", "ARL.Frame.ScrollFrame", ARL.Frame, "UIPanelScrollFrameTemplate")
	
		ARL.Frame.ScrollFrame:ClearAllPoints()
		ARL.Frame.ScrollFrame:SetPoint("TOPLEFT", ARL.Frame, "TOPLEFT", 10, -30)
		ARL.Frame.ScrollFrame:SetHeight(360)
		ARL.Frame.ScrollFrame:SetWidth(344)
		ARL.Frame.ScrollFrame:EnableMouseWheel(true)
		ARL.Frame.ScrollFrame:EnableMouse(true)

		ARL.Frame.ScrollChild = CreateFrame("Frame", "ARL.Frame.ScrollChild", ARL.Frame.ScrollFrame)

		ARL.Frame.ScrollChild:ClearAllPoints()
		ARL.Frame.ScrollChild:SetPoint("TOPLEFT", ARL.Frame.ScrollFrame, "TOPLEFT", 10, -30)
		ARL.Frame.ScrollChild:SetWidth(340)
		ARL.Frame.ScrollChild:SetHeight(355)
		ARL.Frame.ScrollChild:EnableMouseWheel(true)
		ARL.Frame.ScrollChild:EnableMouse(true)

		ARL.Frame.ScrollFrame:SetScrollChild(ARL.Frame.ScrollChild)

		-- Add progress bar to frame
		ARL.Frame.ProgressBar = CreateFrame("StatusBar", "ARL.Frame.ProgressBar", ARL.Frame)
		
		ARL.Frame.ProgressBar:SetWidth(260)
		ARL.Frame.ProgressBar:SetHeight(20)
		ARL.Frame.ProgressBar:ClearAllPoints()
		ARL.Frame.ProgressBar:SetPoint("BOTTOMLEFT", ARL.Frame, 10, 10)
		ARL.Frame.ProgressBar:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
		ARL.Frame.ProgressBar:SetOrientation("HORIZONTAL")
		ARL.Frame.ProgressBar:SetStatusBarColor(0.25, 0.25, 0.75)

		ARL.Frame.ProgressBarBorder = CreateFrame("Button", "ARL.Frame.ProgressBarBorder", ARL.Frame.ProgressBar)

		-- Add border to status bar
		ARL.Frame.ProgressBarBorder:SetNormalTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-BarBorder")
		ARL.Frame.ProgressBarBorder:SetWidth(270)
		ARL.Frame.ProgressBarBorder:SetHeight(40)
		ARL.Frame.ProgressBarBorder:ClearAllPoints()
		ARL.Frame.ProgressBarBorder:SetPoint("CENTER", ARL.Frame.ProgressBar, "CENTER", 0, 0)

		ARL.Frame.ProgressBarText = ARL.Frame.ProgressBar:CreateFontString("ARL.Frame.ProgressBarText", "ARTWORK")

		-- Add text to header frame
		ARL.Frame.ProgressBarText:SetFontObject(GameFontHighlightSmall)
		ARL.Frame.ProgressBarText:ClearAllPoints()
		ARL.Frame.ProgressBarText:SetPoint("CENTER", ARL.Frame.ProgressBar, "CENTER", 0, 0)

		-- Adds Profession header text
		ARL.Frame.ProfessionText = ARL.Frame.ScrollChild:CreateFontString(nil, "ARTWORK", "GameFontNormal")
		ARL.Frame.ProfessionText:SetTextColor(1.0, 1.0, 0.1)
		ARL.Frame.ProfessionText:ClearAllPoints()
		ARL.Frame.ProfessionText:SetPoint("TOP", 0, 0)

	end

	ARL.Frame:ClearAllPoints()

	-- Anchor the frame to a specific window

	-- Anchors to Skillet window
	if (Skillet and Skillet:IsActive() and not CraftIsPetTraining()) then
		ARL.Frame:SetPoint("LEFT", SkilletFrame, "RIGHT", 0, 0)
	-- Anchor to Beast window if skillet is active
	elseif (Skillet and Skillet:IsActive() and CraftIsPetTraining()) then
		ARL.Frame:SetPoint("RIGHT", CraftFrame, "RIGHT", 345, 30)
	-- Anchor to ATSW
	elseif (ATSWFrame) then
		ARL.Frame:SetPoint("RIGHT", ATSWFrame, "RIGHT", 350, 25)
	-- Anchor to trade skill window
	elseif (ARL.SkillType == "Trade") then
		ARL.Frame:SetPoint("RIGHT", TradeSkillFrame, "RIGHT", 345, 30)
	-- Anchor to crafting window
	elseif (ARL.SkillType == "Craft") then
		ARL.Frame:SetPoint("RIGHT", CraftFrame, "RIGHT", 345, 30)
	-- Nothing found to anchor, just put it up in the middle
	else
		ARL.Frame:SetPoint("CENTER", UIParent, "CENTER", 0, 0)
	end

	-- Set the text / status bar display  of the progress bar
	if (CurrentSpeciality == "") then
		ARL.Frame.ProfessionText:SetText(CurrentProfession)
	else
		ARL.Frame.ProfessionText:SetText(CurrentProfession .. " - " .. CurrentSpeciality)
	end

	ARL.Frame:Show()

	-- Add frame elements
	ARL_AddRecipeInfo(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

	-- Include filtered recipes in overall count
	if (ARL.db.profile.includefiltered) then
		ARL.Frame.ProgressBar:SetMinMaxValues(0, ARL.NumberOfRecipes)
		ARL.Frame.ProgressBar:SetValue(ARL.FoundRecipes)
		ARL.Frame.ProgressBarText:SetText(ARL.FoundRecipes .. " \\ " .. ARL.NumberOfRecipes .. " - " .. math.floor(ARL.FoundRecipes / ARL.NumberOfRecipes * 100) .. "%")
	-- Do not include filtered recipes
	else
		ARL.Frame.ProgressBar:SetMinMaxValues(0, ARL.NumberOfRecipes - ARL.FilteredRecipes)
		ARL.Frame.ProgressBar:SetValue(ARL.FoundRecipes)
		ARL.Frame.ProgressBarText:SetText(ARL.FoundRecipes .. " \\ " .. ARL.NumberOfRecipes - ARL.FilteredRecipes .. " - " .. math.floor(ARL.FoundRecipes / (ARL.NumberOfRecipes - ARL.FilteredRecipes) * 100) .. "%")
	end

end

